@@ -30,7 +30,9 @@
 
 package com.twelvemonkeys.imageio.plugins.bmp;
 
-import java.awt.image.BufferedImage;
+import javax.imageio.IIOException;
+import java.awt.image.*;
+import java.io.IOException;
 
 /**
  * Represents bitmap structures we can't read.
@@ -39,16 +41,17 @@ import java.awt.image.BufferedImage;
  * @author <a href="mailto:harald.kuhr@gmail.com">Harald Kuhr</a>
  * @version $Id: BitmapUnsupported.java,v 1.0 25.feb.2006 00:29:44 haku Exp$
  */
-class BitmapUnsupported extends BitmapDescriptor {
-    private String message;
+final class BitmapUnsupported extends BitmapDescriptor {
+    private final String message;
 
-    public BitmapUnsupported(final DirectoryEntry pEntry, final String pMessage) {
-        super(pEntry, null);
+    public BitmapUnsupported(final DirectoryEntry entry, DIBHeader header, final String message) {
+        super(entry, header);
 
-        message = pMessage;
+        this.message = message;
     }
 
-    public BufferedImage getImage() {
-        throw new IllegalStateException(message);
+    @Override
+    public BufferedImage getImage() throws IOException {
+        throw new IIOException(message);
     }
 }
