@@ -30,12 +30,12 @@
 
 package com.twelvemonkeys.imageio.metadata;
 
-import com.twelvemonkeys.lang.Validate;
-import com.twelvemonkeys.util.CollectionUtil;
-
 import java.lang.reflect.Array;
 import java.util.Arrays;
 
+import com.twelvemonkeys.lang.Validate;
+import com.twelvemonkeys.util.CollectionUtil;
+
 /**
  * AbstractEntry
  *
@@ -60,10 +60,10 @@ public abstract class AbstractEntry implements Entry {
     }
 
     /**
-     * Returns a format-native identifier. 
-     * For example {@code "2:00"} for IPTC "Record Version" field, or {@code "0x040c"} for PSD "Thumbnail" resource. 
+     * Returns a format-native identifier.
+     * For example {@code "2:00"} for IPTC "Record Version" field, or {@code "0x040c"} for PSD "Thumbnail" resource.
      * This default implementation simply returns {@code String.valueOf(getIdentifier())}.
-     * 
+     *
      * @return a format-native identifier.
      */
     protected String getNativeIdentifier() {
@@ -84,17 +84,21 @@ public abstract class AbstractEntry implements Entry {
     }
 
     public String getValueAsString() {
-        if (valueCount() > 1) {
-            if (valueCount() < 16) {
+        int count = valueCount();
+
+        if (count == 0 && value != null && value.getClass().isArray() && Array.getLength(value) == 0) {
+            return "";
+        }
+        if (count > 1) {
+            if (count < 16) {
                 return arrayToString(value);
             }
             else {
                 String first = arrayToString(CollectionUtil.subArray(value, 0, 4));
-                String last = arrayToString(CollectionUtil.subArray(value, valueCount() - 4, 4));
-                return String.format("%s ... %s (%d)", first.substring(0, first.length() - 1), last.substring(1), valueCount());
+                String last = arrayToString(CollectionUtil.subArray(value, count - 4, 4));
+                return String.format("%s ... %s (%d)", first.substring(0, first.length() - 1), last.substring(1), count);
             }
         }
-
         if (value != null && value.getClass().isArray() && Array.getLength(value) == 1) {
             return String.valueOf(Array.get(value, 0));
         }
@@ -174,7 +178,7 @@ public abstract class AbstractEntry implements Entry {
         }
 
         AbstractEntry other = (AbstractEntry) pOther;
-        
+
         return identifier.equals(other.identifier) && (
                 value == null && other.value == null || value != null && valueEquals(other)
         );
