@@ -33,10 +33,10 @@ package com.twelvemonkeys.imageio.plugins.tga;
 import javax.imageio.IIOException;
 import javax.imageio.stream.ImageInputStream;
 import java.io.IOException;
-import java.nio.charset.StandardCharsets;
 import java.util.Calendar;
 
 import static com.twelvemonkeys.imageio.plugins.tga.TGA.EXT_AREA_SIZE;
+import static com.twelvemonkeys.imageio.plugins.tga.TGAHeader.readString;
 
 /**
  * TGAExtensions.
@@ -69,9 +69,7 @@ final class TGAExtensions {
     TGAExtensions() {
     }
 
-    static TGAExtensions read(final ImageInputStream stream) throws IOException {
-        int extSize = stream.readUnsignedShort();
-
+    static TGAExtensions read(final ImageInputStream stream, final int extSize) throws IOException {
         // Should always be 495 for version 2.0, no newer version exists.
         // NOTE: Known AutoDesk 3ds Max issue, extension area size field is 494, but still good.
         if (extSize < EXT_AREA_SIZE - 1) {
@@ -84,7 +82,10 @@ final class TGAExtensions {
         extensions.creationDate = readDate(stream);
         extensions.jobId = readString(stream, 41);
 
-        stream.skipBytes(6); // Job time, 3 shorts, hours/minutes/seconds elapsed
+        // Job time, 3 shorts, hours/minutes/seconds elapsed
+        stream.readShort();
+        stream.readShort();
+        stream.readShort();
 
         extensions.softwareId = readString(stream, 41);
 
@@ -148,25 +149,6 @@ final class TGAExtensions {
         return calendar;
     }
 
-    private static String readString(final ImageInputStream stream, final int maxLength) throws IOException {
-        byte[] data = new byte[maxLength];
-        stream.readFully(data);
-
-        return asZeroTerminatedASCIIString(data);
-    }
-
-    private static String asZeroTerminatedASCIIString(final byte[] data) {
-        int len = data.length;
-
-        for (int i = 0; i < data.length; i++) {
-            if (data[i] == 0) {
-                len = i;
-            }
-        }
-
-        return new String(data, 0, len, StandardCharsets.US_ASCII);
-    }
-
     public boolean hasAlpha() {
         switch (attributeType) {
             case 3:
