@@ -47,7 +47,7 @@ import javax.imageio.metadata.IIOMetadataFormatImpl;
 import javax.imageio.spi.ImageReaderSpi;
 import javax.imageio.stream.ImageInputStream;
 import java.awt.*;
-import java.awt.color.ColorSpace;
+import java.awt.color.*;
 import java.awt.image.*;
 import java.io.DataInput;
 import java.io.File;
@@ -538,10 +538,8 @@ final class TGAImageReader extends ImageReaderBase {
 
     @Override
     public IIOMetadata getImageMetadata(final int imageIndex) throws IOException {
-        checkBounds(imageIndex);
-        readHeader();
-
-        return new TGAMetadata(header, extensions);
+        ImageTypeSpecifier rawType = getRawImageType(imageIndex);
+        return new TGAMetadata(rawType, header, extensions);
     }
 
     public static void main(String[] args) throws IOException {
