@@ -30,6 +30,22 @@
 
 package com.twelvemonkeys.imageio.plugins.tiff;
 
+import static com.twelvemonkeys.imageio.plugins.tiff.TIFFImageReader.guessPhotometricInterpretation;
+
+import java.lang.reflect.Array;
+import java.text.DateFormat;
+import java.text.ParseException;
+import java.text.SimpleDateFormat;
+import java.util.*;
+
+import javax.imageio.metadata.IIOInvalidTreeException;
+import javax.imageio.metadata.IIOMetadataFormatImpl;
+import javax.imageio.metadata.IIOMetadataNode;
+
+import org.w3c.dom.Element;
+import org.w3c.dom.Node;
+import org.w3c.dom.NodeList;
+
 import com.twelvemonkeys.imageio.AbstractMetadata;
 import com.twelvemonkeys.imageio.metadata.Directory;
 import com.twelvemonkeys.imageio.metadata.Entry;
@@ -38,18 +54,6 @@ import com.twelvemonkeys.imageio.metadata.tiff.Rational;
 import com.twelvemonkeys.imageio.metadata.tiff.TIFF;
 import com.twelvemonkeys.imageio.metadata.tiff.TIFFEntry;
 import com.twelvemonkeys.lang.Validate;
-import org.w3c.dom.Element;
-import org.w3c.dom.Node;
-import org.w3c.dom.NodeList;
-
-import javax.imageio.metadata.IIOInvalidTreeException;
-import javax.imageio.metadata.IIOMetadataFormatImpl;
-import javax.imageio.metadata.IIOMetadataNode;
-import java.lang.reflect.Array;
-import java.text.DateFormat;
-import java.text.ParseException;
-import java.text.SimpleDateFormat;
-import java.util.*;
 
 /**
  * TIFFImageMetadata.
@@ -84,7 +88,7 @@ public final class TIFFImageMetadata extends AbstractMetadata {
      * or {@link #mergeTree(String, Node)} methods.
      */
     public TIFFImageMetadata(final Directory ifd) {
-        super(true, TIFFMedataFormat.SUN_NATIVE_IMAGE_METADATA_FORMAT_NAME, TIFFMedataFormat.class.getName(), null, null);
+        super(true, TIFFImageMetadataFormat.SUN_NATIVE_IMAGE_METADATA_FORMAT_NAME, TIFFImageMetadataFormat.class.getName(), null, null);
         this.ifd = Validate.notNull(ifd, "IFD");
         this.original = ifd;
     }
@@ -96,7 +100,7 @@ public final class TIFFImageMetadata extends AbstractMetadata {
      * {@link #setFromTree(String, Node)}
      * or {@link #mergeTree(String, Node)} methods.
      */
-    public TIFFImageMetadata(final Collection<Entry> entries) {
+    public TIFFImageMetadata(final Collection<? extends Entry> entries) {
         this(new IFD(entries));
     }
 
@@ -192,7 +196,12 @@ public final class TIFFImageMetadata extends AbstractMetadata {
             elementNode.setAttribute("value", String.valueOf((Short) value & 0xFFFF));
         }
         else if (unsigned && value instanceof Integer) {
-            elementNode.setAttribute("value", String.valueOf((Integer) value & 0xFFFFFFFFl));
+            elementNode.setAttribute("value", String.valueOf((Integer) value & 0xFFFFFFFFL));
+        }
+        else if (value instanceof Rational) {
+            // For compatibility with JAI format, we need denominator
+            String rational = String.valueOf(value);
+            elementNode.setAttribute("value", rational.indexOf('/') < 0 && !"NaN".equals(rational) ? rational + "/1" : rational);
         }
         else {
             elementNode.setAttribute("value", String.valueOf(value));
@@ -353,8 +362,7 @@ public final class TIFFImageMetadata extends AbstractMetadata {
         IIOMetadataNode chroma = new IIOMetadataNode("Chroma");
 
         // Handle ColorSpaceType (RGB/CMYK/YCbCr etc)...
-        Entry photometricTag = ifd.getEntryById(TIFF.TAG_PHOTOMETRIC_INTERPRETATION);
-        int photometricValue = getValueAsInt(photometricTag); // No default for this tag!
+        int photometricValue = getPhotometricInterpretationWithFallback(); // No default for this tag!
         int numChannelsValue = getSamplesPerPixelWithFallback();
 
         IIOMetadataNode colorSpaceType = new IIOMetadataNode("ColorSpaceType");
@@ -445,6 +453,13 @@ public final class TIFFImageMetadata extends AbstractMetadata {
         return chroma;
     }
 
+    private int getPhotometricInterpretationWithFallback() {
+        Entry photometricTag = ifd.getEntryById(TIFF.TAG_PHOTOMETRIC_INTERPRETATION);
+
+        return photometricTag != null ? getValueAsInt(photometricTag)
+                                      : guessPhotometricInterpretation(getCompression(), getSamplesPerPixelWithFallback(), ifd.getEntryById(TIFF.TAG_EXTRA_SAMPLES), ifd.getEntryById(TIFF.TAG_COLOR_MAP));
+    }
+
     private int getSamplesPerPixelWithFallback() {
         // SamplePerPixel defaults to 1, but we'll check BitsPerSample to be sure
         Entry samplesPerPixelTag = ifd.getEntryById(TIFF.TAG_SAMPLES_PER_PIXEL);
@@ -455,15 +470,19 @@ public final class TIFFImageMetadata extends AbstractMetadata {
                                : bitsPerSampleTag != null ? bitsPerSampleTag.valueCount() : 1;
     }
 
+    private int getCompression() {
+        Entry compressionTag = ifd.getEntryById(TIFF.TAG_COMPRESSION);
+        return compressionTag == null
+               ? TIFFBaseline.COMPRESSION_NONE
+               : getValueAsInt(compressionTag);
+    }
+
     @Override
     protected IIOMetadataNode getStandardCompressionNode() {
         IIOMetadataNode compression = new IIOMetadataNode("Compression");
         IIOMetadataNode compressionTypeName = addChildNode(compression, "CompressionTypeName", null);
 
-        Entry compressionTag = ifd.getEntryById(TIFF.TAG_COMPRESSION);
-        int compressionValue = compressionTag == null
-                               ? TIFFBaseline.COMPRESSION_NONE
-                               : getValueAsInt(compressionTag);
+        int compressionValue = getCompression();
 
         // Naming is identical to JAI ImageIO metadata as far as possible
         switch (compressionValue) {
@@ -985,12 +1004,12 @@ public final class TIFFImageMetadata extends AbstractMetadata {
         //      - If set, set res unit to pixels per cm as this better reflects values?
         //      - Or, convert to DPI, if we already had values in DPI??
         //      Also, if we have only aspect, set these values, and use unknown as unit?
-        // TODO: ImageOrientation => Orientation
         NodeList children = dimensionNode.getChildNodes();
 
         Float aspect = null;
         Float xRes = null;
         Float yRes = null;
+        Integer orientation = null;
 
         for (int i = 0; i < children.getLength(); i++) {
             Node child = children.item(i);
@@ -1005,6 +1024,9 @@ public final class TIFFImageMetadata extends AbstractMetadata {
             else if ("VerticalPixelSize".equals(nodeName)) {
                 yRes = Float.parseFloat(getAttribute(child, "value"));
             }
+            else if ("ImageOrientation".equals(nodeName)) {
+                orientation = toTIFFOrientation(getAttribute(child, "value"));
+            }
         }
 
         // If we have one size compute the other
@@ -1051,6 +1073,11 @@ public final class TIFFImageMetadata extends AbstractMetadata {
                     new TIFFEntry(TIFF.TAG_RESOLUTION_UNIT, TIFF.TYPE_SHORT, TIFFBaseline.RESOLUTION_UNIT_NONE));
         }
         // Else give up...
+
+        if (orientation != null) {
+            entries.put(TIFF.TAG_ORIENTATION,
+                    new TIFFEntry(TIFF.TAG_ORIENTATION, TIFF.TYPE_SHORT, orientation.shortValue()));
+        }
     }
 
     private void mergeFromStandardDocumentNode(final Node documentNode, final Map<Integer, Entry> entries) {
@@ -1176,6 +1203,34 @@ public final class TIFFImageMetadata extends AbstractMetadata {
         }
     }
 
+    private Integer toTIFFOrientation(String imageOrientation) {
+        if (imageOrientation == null) {
+            // malformed, empty or not readable value
+            return null;
+        }
+        switch (imageOrientation.toLowerCase()) {
+            case "normal":
+                return TIFFBaseline.ORIENTATION_TOPLEFT;
+            case "fliph":
+                return TIFFExtension.ORIENTATION_TOPRIGHT;
+            case "rotate180":
+                return TIFFExtension.ORIENTATION_BOTRIGHT;
+            case "flipv":
+                return TIFFExtension.ORIENTATION_BOTLEFT;
+            case "fliphrotate90":
+                return TIFFExtension.ORIENTATION_LEFTTOP;
+            case "rotate270":
+                return TIFFExtension.ORIENTATION_RIGHTTOP;
+            case "flipvrotate90":
+                return TIFFExtension.ORIENTATION_RIGHTBOT;
+            case "rotate90":
+                return TIFFExtension.ORIENTATION_LEFTBOT;
+            default:
+                // malformed, invalid value
+                return null;
+        }
+    }
+
     private short getTIFFType(final Node node) throws IIOInvalidTreeException {
         Node containerNode = node.getFirstChild();
         if (containerNode == null) {
