@@ -40,6 +40,7 @@ import com.twelvemonkeys.imageio.metadata.tiff.TIFFEntry;
 import com.twelvemonkeys.imageio.metadata.tiff.TIFFWriter;
 import com.twelvemonkeys.imageio.stream.SubImageOutputStream;
 import com.twelvemonkeys.imageio.util.IIOUtil;
+import com.twelvemonkeys.imageio.util.ImageTypeSpecifiers;
 import com.twelvemonkeys.imageio.util.ProgressListenerBase;
 import com.twelvemonkeys.io.enc.EncoderStream;
 import com.twelvemonkeys.io.enc.PackBitsEncoder;
@@ -149,9 +150,9 @@ public final class TIFFImageWriter extends ImageWriterBase {
         RenderedImage renderedImage = image.getRenderedImage();
         SampleModel sampleModel = renderedImage.getSampleModel();
 
-        // Can't use createFromRenderedImage in this case, as it does not consider palette for TYPE_BYTE_BINARY...
-        // TODO: Consider writing workaround in ImageTypeSpecifiers
-        ImageTypeSpecifier spec = new ImageTypeSpecifier(renderedImage);
+        // Need ImageTypeSpecifiers.createFromRenderedImage in this case, as the JDK method does not consider
+        // palette for TYPE_BYTE_BINARY/TYPE_BYTE_INDEXED...
+        ImageTypeSpecifier spec = ImageTypeSpecifiers.createFromRenderedImage(renderedImage);
 
         // TODO: Handle case where convertImageMetadata returns null, due to unknown metadata format, or reconsider if that's a valid case...
         TIFFImageMetadata metadata = image.getMetadata() != null
@@ -249,7 +250,7 @@ public final class TIFFImageWriter extends ImageWriterBase {
                 ListenerDelegate listener = new ListenerDelegate(imageIndex);
                 jpegWriter.addIIOWriteProgressListener(listener);
                 jpegWriter.addIIOWriteWarningListener(listener);
-                jpegWriter.write(null, image, copyParams(param, jpegWriter));
+                jpegWriter.write(null, imageOnly(image), copyParams(param, jpegWriter));
             }
             finally {
                 jpegWriter.dispose();
@@ -284,6 +285,17 @@ public final class TIFFImageWriter extends ImageWriterBase {
         return nextIFDPointerOffset;
     }
 
+    private IIOImage imageOnly(final IIOImage image) {
+        if (image.getMetadata() == null && image.getNumThumbnails() == 0) {
+            // Just image data here, no need to copy
+            return image;
+        }
+
+        return image.hasRaster()
+                ? new IIOImage(image.getRaster(), null, null)
+                : new IIOImage(image.getRenderedImage(), null, null);
+    }
+
     // TODO: Candidate util method
     private ImageWriteParam copyParams(final ImageWriteParam param, final ImageWriter writer) {
         if (param == null) {
@@ -531,6 +543,10 @@ public final class TIFFImageWriter extends ImageWriterBase {
         final int sampleSize = renderedImage.getSampleModel().getSampleSize(0);
         final int numBands = renderedImage.getSampleModel().getNumBands();
 
+        // TODO: This buffer should probably have order matching that of imageOutput, but only if writing "actual" 16 or 32 bit samples, not "packed" samples
+        final byte[] buffer = new byte[(tileWidth * numBands * sampleSize + 7) / 8];
+        int bufferPos = 0;
+
         for (int yTile = minTileY; yTile < maxYTiles; yTile++) {
             for (int xTile = minTileX; xTile < maxXTiles; xTile++) {
                 final Raster tile = renderedImage.getTile(xTile, yTile);
@@ -568,16 +584,17 @@ public final class TIFFImageWriter extends ImageWriterBase {
                                     for (int s = 0; s < numBands; s++) {
                                         if (sampleSize == 8 || shift == 0) {
                                             // Normal interleaved/planar case
-                                            stream.writeByte((byte) (dataBuffer.getElem(b, xOff + bandOffsets[s]) & 0xff));
-
+                                            buffer[bufferPos++] = ((byte) (dataBuffer.getElem(b, xOff + bandOffsets[s]) & 0xff));
                                         }
                                         else {
                                             // "Packed" case
-                                            stream.writeByte((byte) (rowBuffer.getElem(b, x - offsetX + bandOffsets[s]) & 0xff));
+                                            buffer[bufferPos++] = ((byte) (rowBuffer.getElem(b, x - offsetX + bandOffsets[s]) & 0xff));
                                         }
                                     }
                                 }
 
+                                flushBuffer(buffer, bufferPos, stream);
+                                bufferPos = 0;
                                 flushStream(stream);
                             }
                         }
@@ -597,9 +614,13 @@ public final class TIFFImageWriter extends ImageWriterBase {
                                     for (int x = offsetX; x < tileWidth + offsetX; x++) {
                                         int xOff = yOff + x;
 
-                                        stream.writeShort((short) (dataBuffer.getElem(b, xOff) & 0xffff));
+                                        int elem = dataBuffer.getElem(b, xOff);
+                                        buffer[bufferPos++] = (byte) ((elem >>> 8) & 0xff);
+                                        buffer[bufferPos++] = (byte) (elem & 0xff);
                                     }
 
+                                    flushBuffer(buffer, bufferPos, stream);
+                                    bufferPos = 0;
                                     flushStream(stream);
                                 }
                             }
@@ -642,9 +663,15 @@ public final class TIFFImageWriter extends ImageWriterBase {
                                     for (int x = offsetX; x < tileWidth + offsetX; x++) {
                                         int xOff = yOff + x;
 
-                                        stream.writeInt(dataBuffer.getElem(b, xOff));
+                                        int elem = dataBuffer.getElem(b, xOff);
+                                        buffer[bufferPos++] = (byte) ((elem >>> 24) & 0xff);
+                                        buffer[bufferPos++] = (byte) ((elem >>> 16) & 0xff);
+                                        buffer[bufferPos++] = (byte) ((elem >>> 8) & 0xff);
+                                        buffer[bufferPos++] = (byte) (elem & 0xff);
                                     }
 
+                                    flushBuffer(buffer, bufferPos, stream);
+                                    bufferPos = 0;
                                     flushStream(stream);
                                 }
                             }
@@ -661,10 +688,12 @@ public final class TIFFImageWriter extends ImageWriterBase {
                                         int element = dataBuffer.getElem(b, xOff);
 
                                         for (int s = 0; s < numBands; s++) {
-                                            stream.writeByte((byte) ((element >> bitOffsets[s]) & 0xff));
+                                            buffer[bufferPos++] = (byte) ((element >> bitOffsets[s]) & 0xff);
                                         }
                                     }
 
+                                    flushBuffer(buffer, bufferPos, stream);
+                                    bufferPos = 0;
                                     flushStream(stream);
                                 }
                             }
@@ -690,14 +719,18 @@ public final class TIFFImageWriter extends ImageWriterBase {
         processImageComplete();
     }
 
-    private void flushStream(DataOutput stream) throws IOException {
-        // Need to flush/start new compression for each row, for proper LZW/PackBits/Deflate/ZLib compression
+    private static void flushStream(DataOutput stream) throws IOException {
+        // Need to flush/start new compression for each row, for proper LZW/PackBits/Deflate/ZLib
         if (stream instanceof DataOutputStream) {
             DataOutputStream dataOutputStream = (DataOutputStream) stream;
             dataOutputStream.flush();
         }
     }
 
+    private static void flushBuffer(final byte[] buffer, final int bufferPos, final DataOutput stream) throws IOException {
+        stream.write(buffer, 0, bufferPos);
+    }
+
     // Metadata
 
     @Override
