@@ -61,6 +61,7 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
+import static com.twelvemonkeys.imageio.plugins.webp.lossless.VP8LDecoder.copyIntoRasterWithParams;
 import static java.lang.Math.max;
 import static java.lang.Math.min;
 
@@ -76,6 +77,11 @@ final class WebPImageReader extends ImageReaderBase {
     // Either VP8_, VP8L or VP8X chunk
     private long fileSize;
     private VP8xChunk header;
+
+    // The ICC Profile contained in the stream, only suitable for metadata.
+    private ICC_Profile containedICCP;
+
+    // A safe, verified RGB ICC Profile used for color conversion.
     private ICC_Profile iccProfile;
     private final List<AnimationFrame> frames = new ArrayList<>();
 
@@ -87,6 +93,7 @@ final class WebPImageReader extends ImageReaderBase {
     protected void resetMembers() {
         fileSize = -1;
         header = null;
+        containedICCP = null;
         iccProfile = null;
         lsbBitReader = null;
         frames.clear();
@@ -132,8 +139,8 @@ final class WebPImageReader extends ImageReaderBase {
 
             if (DEBUG) {
                 System.out.printf("chunk: '%s'\n", fourCC(nextChunk));
-                System.out.println("chunkLength: " + chunkLength);
                 System.out.println("chunkStart: " + chunkStart);
+                System.out.println("chunkLength: " + chunkLength);
             }
 
             switch (nextChunk) {
@@ -298,13 +305,20 @@ final class WebPImageReader extends ImageReaderBase {
 
                 if (header.containsICCP) {
                     // ICCP chunk must be first chunk, if present
-                    while (iccProfile == null && imageInput.getStreamPosition() < fileSize) {
+                    while (containedICCP == null && imageInput.getStreamPosition() < fileSize) {
                         int nextChunk = imageInput.readInt();
                         long chunkLength = imageInput.readUnsignedInt();
                         long chunkStart = imageInput.getStreamPosition();
 
                         if (nextChunk == WebP.CHUNK_ICCP) {
-                            iccProfile = ColorProfiles.readProfile(IIOUtil.createStreamAdapter(imageInput, chunkLength));
+                            containedICCP = ColorProfiles.readProfile(IIOUtil.createStreamAdapter(imageInput, chunkLength));
+
+                            if (containedICCP.getColorSpaceType() == ColorSpace.TYPE_RGB) {
+                                iccProfile = containedICCP;
+                            }
+                            else {
+                                processWarningOccurred("Encountered non-RGB ICC Profile, ignoring color profile, colors may appear incorrect");
+                            }
                         }
                         else {
                             processWarningOccurred(String.format("Expected 'ICCP' chunk, '%s' chunk encountered", fourCC(nextChunk)));
@@ -385,9 +399,10 @@ final class WebPImageReader extends ImageReaderBase {
 
         if (iccProfile != null && !ColorProfiles.isCS_sRGB(iccProfile)) {
             ICC_ColorSpace colorSpace = ColorSpaces.createColorSpace(iccProfile);
-            int[] bandOffsets = header.containsALPH ? new int[] {0, 1, 2, 3} : new int[] {0, 1, 2};
+            int[] bandOffsets = header.containsALPH ? new int[]{0, 1, 2, 3} : new int[]{0, 1, 2};
             return ImageTypeSpecifiers.createInterleaved(colorSpace, bandOffsets, DataBuffer.TYPE_BYTE, header.containsALPH, false);
         }
+        // Non-RGB profile is simply ignored
 
         return ImageTypeSpecifiers.createFromBufferedImageType(header.containsALPH ? BufferedImage.TYPE_4BYTE_ABGR : BufferedImage.TYPE_3BYTE_BGR);
     }
@@ -464,6 +479,8 @@ final class WebPImageReader extends ImageReaderBase {
     }
 
     private void readVP8Extended(BufferedImage destination, ImageReadParam param, long streamEnd, final int width, final int height) throws IOException {
+        boolean seenALPH = false;
+
         while (imageInput.getStreamPosition() < streamEnd) {
             int nextChunk = imageInput.readInt();
             long chunkLength = imageInput.readUnsignedInt();
@@ -471,18 +488,25 @@ final class WebPImageReader extends ImageReaderBase {
 
             if (DEBUG) {
                 System.out.printf("chunk: '%s'\n", fourCC(nextChunk));
-                System.out.println("chunkLength: " + chunkLength);
                 System.out.println("chunkStart: " + chunkStart);
+                System.out.println("chunkLength: " + chunkLength);
             }
 
             switch (nextChunk) {
                 case WebP.CHUNK_ALPH:
+                    seenALPH = true;
                     readAlpha(destination, param, width, height);
                     break;
 
                 case WebP.CHUNK_VP8_:
                     readVP8(RasterUtils.asByteRaster(destination.getRaster())
                             .createWritableChild(0, 0, destination.getWidth(), destination.getHeight(), 0, 0, new int[] {0, 1, 2}), param);
+
+                    if (header.containsALPH && !seenALPH) {
+                        // May happen for animation frames, if some frames are fully opaque
+                        opaqueAlpha(destination.getAlphaRaster());
+                    }
+
                     break;
 
                 case WebP.CHUNK_VP8L:
@@ -536,21 +560,26 @@ final class WebPImageReader extends ImageReaderBase {
                 // Simulate header
                 imageInput.seek(imageInput.getStreamPosition() - 5);
 
-                WritableRaster tempRaster = Raster.createInterleavedRaster(DataBuffer.TYPE_BYTE, destination.getWidth(), destination.getHeight(), 4, null);
-                readVP8Lossless(tempRaster, param, width, height);
+                // Temp alpha raster must have same dimensions as the source, because of filtering.
+                WritableRaster tempRaster = Raster.createInterleavedRaster(DataBuffer.TYPE_BYTE, width, height, 4, null);
+                readVP8Lossless(tempRaster, null, width, height);
 
                 // Copy from green (band 1) in temp to alpha in destination
-                alphaRaster.setRect(tempRaster.createChild(0, 0, tempRaster.getWidth(), tempRaster.getHeight(), 0, 0, new int[] {1}));
+                WritableRaster alphaChannel = tempRaster.createWritableChild(0, 0, tempRaster.getWidth(), tempRaster.getHeight(), 0, 0, new int[]{1});
+                alphaFilter(alphaChannel, filtering);
+                copyIntoRasterWithParams(alphaChannel, alphaRaster, param);
                 break;
             default:
                 processWarningOccurred("Unknown WebP alpha compression: " + compression);
                 opaqueAlpha(alphaRaster);
                 break;
         }
+    }
 
+    private void alphaFilter(WritableRaster alphaRaster, int filtering) {
         if (filtering != AlphaFiltering.NONE) {
-            for (int y = 0; y < destination.getHeight(); y++) {
-                for (int x = 0; x < destination.getWidth(); x++) {
+            for (int y = 0; y < alphaRaster.getHeight(); y++) {
+                for (int x = 0; x < alphaRaster.getWidth(); x++) {
                     int predictorAlpha = getPredictorAlpha(alphaRaster, filtering, y, x);
                     alphaRaster.setSample(x, y, 0, alphaRaster.getSample(x, y, 0) + predictorAlpha % 256);
                 }
@@ -677,8 +706,8 @@ final class WebPImageReader extends ImageReaderBase {
                 long chunkStart = imageInput.getStreamPosition();
 
 //                System.err.printf("chunk: '%s'\n", fourCC(nextChunk));
-//                System.err.println("chunkLength: " + chunkLength);
 //                System.err.println("chunkStart: " + chunkStart);
+//                System.err.println("chunkLength: " + chunkLength);
 
                 switch (nextChunk) {
                     case WebP.CHUNK_EXIF:
