@@ -117,7 +117,7 @@ public final class VP8LDecoder {
 
         if (topLevel) {
             Rectangle bounds = new Rectangle(width, height);
-            fullSizeRaster = getRasterForDecoding(raster, param, bounds);
+            fullSizeRaster = createDecodeRaster(raster, param, bounds);
 
             // If multiple indices packed into one pixel xSize is different from raster width
             decodeRaster = fullSizeRaster.createWritableChild(0, 0, xSize, height, 0, 0, null);
@@ -134,40 +134,12 @@ public final class VP8LDecoder {
             transform.applyInverse(fullSizeRaster);
         }
 
-        if (fullSizeRaster != raster && param != null) {
-            // Copy into destination raster with settings applied
-            Rectangle sourceRegion = param.getSourceRegion();
-            int sourceXSubsampling = param.getSourceXSubsampling();
-            int sourceYSubsampling = param.getSourceYSubsampling();
-            int subsamplingXOffset = param.getSubsamplingXOffset();
-            int subsamplingYOffset = param.getSubsamplingYOffset();
-            Point destinationOffset = param.getDestinationOffset();
-
-            if (sourceRegion == null) {
-                sourceRegion = raster.getBounds();
-            }
-
-            if (sourceXSubsampling == 1 && sourceYSubsampling == 1) {
-                // Only apply offset (and limit to requested region)
-                raster.setRect(destinationOffset.x, destinationOffset.y, fullSizeRaster);
-            }
-            else {
-                // Manual copy, more efficient way might exist
-                byte[] rgba = new byte[4];
-                int xEnd = raster.getWidth() + raster.getMinX();
-                int yEnd = raster.getHeight() + raster.getMinY();
-
-                for (int xDst = destinationOffset.x, xSrc = sourceRegion.x + subsamplingXOffset; xDst < xEnd; xDst++, xSrc += sourceXSubsampling) {
-                    for (int yDst = destinationOffset.y, ySrc = sourceRegion.y + subsamplingYOffset; yDst < yEnd; yDst++, ySrc += sourceYSubsampling) {
-                        fullSizeRaster.getDataElements(xSrc, ySrc, rgba);
-                        raster.setDataElements(xDst, yDst, rgba);
-                    }
-                }
-            }
+        if (fullSizeRaster != raster) {
+            copyIntoRasterWithParams(fullSizeRaster, raster, param);
         }
     }
 
-    private WritableRaster getRasterForDecoding(WritableRaster raster, ImageReadParam param, Rectangle bounds) {
+    private WritableRaster createDecodeRaster(WritableRaster raster, ImageReadParam param, Rectangle bounds) {
         // If the ImageReadParam requires only a subregion of the image, and if the whole image does not fit into the
         // Raster or subsampling is requested, we need a temporary Raster as we can only decode the whole image at once
         boolean originSet = false;
@@ -182,9 +154,9 @@ public final class VP8LDecoder {
             else {
                 bounds.setLocation(param.getDestinationOffset());
                 originSet = true;
-
             }
         }
+
         if (!raster.getBounds().contains(bounds)) {
             // Can't reuse existing
             return Raster.createInterleavedRaster(DataBuffer.TYPE_BYTE, bounds.width, bounds.height, 4 * bounds.width,
@@ -192,9 +164,39 @@ public final class VP8LDecoder {
         }
 
         return originSet ?
-               // Recenter to (0, 0)
-               raster.createWritableChild(bounds.x, bounds.y, bounds.width, bounds.height, 0, 0, null) :
-               raster;
+                // Recenter to (0, 0)
+                raster.createWritableChild(bounds.x, bounds.y, bounds.width, bounds.height, 0, 0, null) :
+                raster;
+    }
+
+    /**
+     * Copy a source raster into a destination raster with optional settings applied.
+     */
+    public static void copyIntoRasterWithParams(final Raster srcRaster, final WritableRaster dstRaster, final ImageReadParam param) {
+        Rectangle sourceRegion = param != null && param.getSourceRegion() != null ? param.getSourceRegion() : srcRaster.getBounds();
+        int sourceXSubsampling = param != null ? param.getSourceXSubsampling() : 1;
+        int sourceYSubsampling = param != null ? param.getSourceYSubsampling() : 1;
+        int subsamplingXOffset = param != null ? param.getSubsamplingXOffset() : 0;
+        int subsamplingYOffset = param != null ? param.getSubsamplingYOffset() : 0;
+        Point destinationOffset = param != null ? param.getDestinationOffset() : new Point(0, 0) ;
+
+        if (sourceXSubsampling == 1 && sourceYSubsampling == 1) {
+            // Only apply offset (and limit to requested region)
+            dstRaster.setRect(destinationOffset.x, destinationOffset.y, srcRaster);
+        }
+        else {
+            // Subsampled case
+            byte[] rgba = new byte[4];
+            int xEnd = dstRaster.getWidth() + dstRaster.getMinX();
+            int yEnd = dstRaster.getHeight() + dstRaster.getMinY();
+
+            for (int yDst = destinationOffset.y, ySrc = sourceRegion.y + subsamplingYOffset; yDst < yEnd; yDst++, ySrc += sourceYSubsampling) {
+                for (int xDst = destinationOffset.x, xSrc = sourceRegion.x + subsamplingXOffset; xDst < xEnd; xDst++, xSrc += sourceXSubsampling) {
+                    srcRaster.getDataElements(xSrc, ySrc, rgba);
+                    dstRaster.setDataElements(xDst, yDst, rgba);
+                }
+            }
+        }
     }
 
     private void decodeImage(WritableRaster raster, HuffmanInfo huffmanInfo, ColorCache colorCache) throws IOException {
